<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:output method="xml" indent="yes" encoding="utf-8" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"/>
	<xsl:strip-space elements="*"/>
	<xsl:include href="buttons.xsl"/>

	<xsl:template match="LAYOUT">
		<xsl:variable name="cID" select="@ID"/>
		<!-- aa-13 -->
		<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
		<head>
			<title><xsl:value-of select="@SITE-TITLE" disable-output-escaping="yes"/> - <xsl:value-of select="@TITLE" disable-output-escaping="yes"/></title>
			<xsl:apply-templates select="META-TAGS"/>
			<link href="css/styles.css" rel="stylesheet" type="text/css"/>
		</head>
<body style="margin: 0;">
<div class="container">
	<div class="logo-left-area">
		<div class="logo-area">
			<!-- LOGO -->
			<img src="images/{LOGO/@NAME}" alt="" border="0" align="left"/>
			<div class="logo-text">
				<h1><xsl:value-of select="COMPANY-INFO/NAME" disable-output-escaping="yes"/></h1>
				<div class="subtitle"><xsl:value-of select="COMPANY-INFO/SLOGAN" disable-output-escaping="yes"/></div>
			</div>
			<!-- END LOGO -->
		</div>
	</div>
	<div class="logo-right-area"></div>
	<div class="logo-middle-area"></div>
	<!-- MENU -->
	<xsl:call-template name="TOP-MENU"/>
	<!-- END MENU -->
	<table cellspacing="0" class="header-area">
		<tr>
			<td class="header-left-area"><img src="images/header.gif" alt="" border="0"/></td>
			<td class="header-middle-area"></td>
			<td class="header-right-area">
				<img src="images/header_tr.gif" alt="" border="0"/><div class="submenu-area">
					<!-- SUBMENU -->
					<xsl:call-template name="SUB-MENU"><xsl:with-param name="pageID" select="@ID"/></xsl:call-template>
					<!-- END SUBMENU -->
				</div>
				<img src="images/header_br.gif" alt="" border="0"/></td>
		</tr>
	</table>
	<table cellspacing="0" class="content-area">
		<tr>
			<td class="content-left-area"><img src="images/content_bl.gif" alt="" border="0"/></td>
			<td class="content-middle-area">
				<h2><xsl:value-of select="@TITLE" disable-output-escaping="yes"/></h2>
				<div class="pageContent">
					<!-- CONTENT -->
					<xsl:apply-templates select="PAGE-CONTENT"/>
					<!-- END CONTENT -->
				</div>
			</td>
			<td class="content-right-area"><div><span></span></div></td>
		</tr>
	</table>
	<table cellspacing="0" class="footer-area">
		<tr>
			<td class="footer-left-area"><img src="images/footer_left.gif" alt="" border="0"/></td>
			<td class="footer-left-bg-area"><div><span></span></div></td>
			<td class="footer-middle-area">
				<div>
					<!-- FOOTER -->
					<div class="footer"><xsl:value-of select="COPYRIGHT" disable-output-escaping="yes"/></div>
					<!-- END FOOTER -->
				</div>
			</td>
			<td class="footer-right-bg-area"><div><span></span></div></td>
			<td class="footer-right-area"><img src="images/footer_right.gif" alt="" border="0"/></td>
		</tr>
	</table>
</div>
</body>		
		<!--sw_sb_ms-->
		</html>
	</xsl:template>


<xsl:template name="TOP-MENU">
		<xsl:apply-templates select="MENU" mode="top"/>	
</xsl:template>


<xsl:template name="SUB-MENU">
	<xsl:param name="pageID"/>	
	<xsl:if test="//MENU/MENU-ITEM[@ID = $pageID]/MENU-ITEM or //MENU/MENU-ITEM/MENU-ITEM[@ID = $pageID]">
		<ul class="submenu">
			<xsl:choose>
				<xsl:when test="//MENU/MENU-ITEM[@ID = $pageID]/MENU-ITEM">
					<xsl:apply-templates select="//MENU/MENU-ITEM[@ID = $pageID]/MENU-ITEM" mode="sub"/>
				</xsl:when>
				<xsl:when test="//MENU/MENU-ITEM/MENU-ITEM[@ID = $pageID]">
					<xsl:variable name="parentID" select="//MENU/MENU-ITEM/MENU-ITEM[@ID = $pageID]/../@ID"/>
					<xsl:apply-templates select="//MENU/MENU-ITEM[@ID=$parentID]/MENU-ITEM" mode="sub"/>
				</xsl:when>
			</xsl:choose>
		</ul>
	</xsl:if>
</xsl:template>		
	
<xsl:template match="MENU-ITEM" mode="sub">
	<xsl:choose>
		<!--active-->
		<xsl:when test="@ID=/LAYOUT/@ID" >
			<li class="active"><a href="{@HREF}"><xsl:value-of select="@TITLE" disable-output-escaping="yes"/></a></li>
		</xsl:when>
		<!--inactive-->
		<xsl:otherwise>
			<xsl:if test="../MENU-ITEM[@ID=/LAYOUT/@ID] or ../../MENU-ITEM[@ID=/LAYOUT/@ID]">
				<li><a href="{@HREF}"><xsl:value-of select="@TITLE" disable-output-escaping="yes"/></a></li>
			</xsl:if>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:if test="position()!=last()">
		<!-- separator -->
		<li class="separator"><div><span></span></div></li>
	</xsl:if>
</xsl:template>	
	
<xsl:template match="META-TAGS">
	<xsl:apply-templates mode="meta-tags"/>
</xsl:template>
	
<xsl:template match="*" mode="meta-tags">
	<meta name="{local-name(.)}"><xsl:attribute name="content"><xsl:value-of select="."/></xsl:attribute></meta>
</xsl:template>


<xsl:template match="PAGE-CONTENT">
	<xsl:comment> EDITABLE CONTENT </xsl:comment>
	<xsl:apply-templates mode="meta-tags"/>
</xsl:template>
	     	
</xsl:stylesheet>
